@@ -46,7 +46,7 @@ from robot.api import ExecutionResult, ResultVisitor
 from robot.utils import Matcher
 
 
-__version__ = "2.0.2"
+__version__ = "2.0.3"
 RF3 = rf_version.startswith("3")
 
 
@@ -262,12 +262,6 @@ class LogMessageChecker(BaseChecker):
         if expected.test_teardown and not test.keywords.teardown:
             self._fail(test, self._no_teardown_message.format(test.name))
             return None
-        if not expected.test_teardown and test.keywords.teardown:
-            self._fail(
-                test,
-                self._teardown_access_message.format(test.name, expected.kw_index_str),
-            )
-            return None
         if (
             test.keywords.setup
             and not expected.test_setup
@@ -284,12 +278,6 @@ class LogMessageChecker(BaseChecker):
         if expected.test_teardown and not test.teardown:
             self._fail(test, self._no_teardown_message.format(test.name))
             return None
-        if not expected.test_teardown and test.teardown:
-            self._fail(
-                test,
-                self._teardown_access_message.format(test.name, expected.kw_index_str),
-            )
-            return None
         if expected.test_setup and not kw:
             kw = test.setup
         elif expected.test_teardown and not kw:
